# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github_com/TheThingsNetwork/api/api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='github_com/TheThingsNetwork/api/api.proto',
  package='api',
  syntax='proto3',
  serialized_pb=_b('\n)github_com/TheThingsNetwork/api/api.proto\x12\x03\x61pi\"\xd1\x01\n\x0bPercentiles\x12\x13\n\x0bpercentile1\x18\x01 \x01(\x02\x12\x13\n\x0bpercentile5\x18\x02 \x01(\x02\x12\x14\n\x0cpercentile10\x18\x03 \x01(\x02\x12\x14\n\x0cpercentile25\x18\x04 \x01(\x02\x12\x14\n\x0cpercentile50\x18\x05 \x01(\x02\x12\x14\n\x0cpercentile75\x18\x06 \x01(\x02\x12\x14\n\x0cpercentile90\x18\x07 \x01(\x02\x12\x14\n\x0cpercentile95\x18\x08 \x01(\x02\x12\x14\n\x0cpercentile99\x18\t \x01(\x02\"5\n\x05Rates\x12\r\n\x05rate1\x18\x01 \x01(\x02\x12\r\n\x05rate5\x18\x02 \x01(\x02\x12\x0e\n\x06rate15\x18\x03 \x01(\x02\"\xd3\x02\n\x0bSystemStats\x12(\n\x04load\x18\x01 \x01(\x0b\x32\x1a.api.SystemStats.Loadstats\x12&\n\x03\x63pu\x18\x02 \x01(\x0b\x32\x19.api.SystemStats.CPUStats\x12,\n\x06memory\x18\x03 \x01(\x0b\x32\x1c.api.SystemStats.MemoryStats\x1a\x39\n\tLoadstats\x12\r\n\x05load1\x18\x01 \x01(\x02\x12\r\n\x05load5\x18\x02 \x01(\x02\x12\x0e\n\x06load15\x18\x03 \x01(\x02\x1aJ\n\x08\x43PUStats\x12\x0c\n\x04user\x18\x01 \x01(\x02\x12\x0e\n\x06system\x18\x02 \x01(\x02\x12\x0c\n\x04idle\x18\x03 \x01(\x02\x12\x12\n\npercentage\x18\x04 \x01(\x02\x1a=\n\x0bMemoryStats\x12\r\n\x05total\x18\x01 \x01(\x04\x12\x11\n\tavailable\x18\x02 \x01(\x04\x12\x0c\n\x04used\x18\x03 \x01(\x04\"\xbf\x02\n\x0e\x43omponentStats\x12\x0e\n\x06uptime\x18\x01 \x01(\x04\x12)\n\x03\x63pu\x18\x02 \x01(\x0b\x32\x1c.api.ComponentStats.CPUStats\x12/\n\x06memory\x18\x03 \x01(\x0b\x32\x1f.api.ComponentStats.MemoryStats\x12\x12\n\ngoroutines\x18\x04 \x01(\x04\x12\x17\n\x0fgc_cpu_fraction\x18\x05 \x01(\x02\x1aJ\n\x08\x43PUStats\x12\x0c\n\x04user\x18\x01 \x01(\x02\x12\x0e\n\x06system\x18\x02 \x01(\x02\x12\x0c\n\x04idle\x18\x03 \x01(\x02\x12\x12\n\npercentage\x18\x04 \x01(\x02\x1aH\n\x0bMemoryStats\x12\x0e\n\x06memory\x18\x01 \x01(\x04\x12\x0c\n\x04swap\x18\x02 \x01(\x04\x12\x0c\n\x04heap\x18\n \x01(\x04\x12\r\n\x05stack\x18\x0b \x01(\x04\x42^\n\x18org.thethingsnetwork.apiB\x08\x41PIProtoP\x01Z\x1fgithub_com/TheThingsNetwork/api\xaa\x02\x14TheThingsNetwork.APIb\x06proto3')
)




_PERCENTILES = _descriptor.Descriptor(
  name='Percentiles',
  full_name='api.Percentiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentile1', full_name='api.Percentiles.percentile1', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile5', full_name='api.Percentiles.percentile5', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile10', full_name='api.Percentiles.percentile10', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile25', full_name='api.Percentiles.percentile25', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile50', full_name='api.Percentiles.percentile50', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile75', full_name='api.Percentiles.percentile75', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile90', full_name='api.Percentiles.percentile90', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile95', full_name='api.Percentiles.percentile95', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile99', full_name='api.Percentiles.percentile99', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=260,
)


_RATES = _descriptor.Descriptor(
  name='Rates',
  full_name='api.Rates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rate1', full_name='api.Rates.rate1', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate5', full_name='api.Rates.rate5', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate15', full_name='api.Rates.rate15', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=315,
)


_SYSTEMSTATS_LOADSTATS = _descriptor.Descriptor(
  name='Loadstats',
  full_name='api.SystemStats.Loadstats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load1', full_name='api.SystemStats.Loadstats.load1', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load5', full_name='api.SystemStats.Loadstats.load5', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load15', full_name='api.SystemStats.Loadstats.load15', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=518,
)

_SYSTEMSTATS_CPUSTATS = _descriptor.Descriptor(
  name='CPUStats',
  full_name='api.SystemStats.CPUStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='api.SystemStats.CPUStats.user', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='system', full_name='api.SystemStats.CPUStats.system', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idle', full_name='api.SystemStats.CPUStats.idle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='api.SystemStats.CPUStats.percentage', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=594,
)

_SYSTEMSTATS_MEMORYSTATS = _descriptor.Descriptor(
  name='MemoryStats',
  full_name='api.SystemStats.MemoryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='api.SystemStats.MemoryStats.total', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='available', full_name='api.SystemStats.MemoryStats.available', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='used', full_name='api.SystemStats.MemoryStats.used', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=657,
)

_SYSTEMSTATS = _descriptor.Descriptor(
  name='SystemStats',
  full_name='api.SystemStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load', full_name='api.SystemStats.load', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='api.SystemStats.cpu', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memory', full_name='api.SystemStats.memory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SYSTEMSTATS_LOADSTATS, _SYSTEMSTATS_CPUSTATS, _SYSTEMSTATS_MEMORYSTATS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=657,
)


_COMPONENTSTATS_CPUSTATS = _descriptor.Descriptor(
  name='CPUStats',
  full_name='api.ComponentStats.CPUStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='api.ComponentStats.CPUStats.user', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='system', full_name='api.ComponentStats.CPUStats.system', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idle', full_name='api.ComponentStats.CPUStats.idle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='api.ComponentStats.CPUStats.percentage', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=594,
)

_COMPONENTSTATS_MEMORYSTATS = _descriptor.Descriptor(
  name='MemoryStats',
  full_name='api.ComponentStats.MemoryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory', full_name='api.ComponentStats.MemoryStats.memory', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swap', full_name='api.ComponentStats.MemoryStats.swap', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heap', full_name='api.ComponentStats.MemoryStats.heap', index=2,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stack', full_name='api.ComponentStats.MemoryStats.stack', index=3,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=979,
)

_COMPONENTSTATS = _descriptor.Descriptor(
  name='ComponentStats',
  full_name='api.ComponentStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uptime', full_name='api.ComponentStats.uptime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='api.ComponentStats.cpu', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memory', full_name='api.ComponentStats.memory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='goroutines', full_name='api.ComponentStats.goroutines', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gc_cpu_fraction', full_name='api.ComponentStats.gc_cpu_fraction', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_COMPONENTSTATS_CPUSTATS, _COMPONENTSTATS_MEMORYSTATS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=979,
)

_SYSTEMSTATS_LOADSTATS.containing_type = _SYSTEMSTATS
_SYSTEMSTATS_CPUSTATS.containing_type = _SYSTEMSTATS
_SYSTEMSTATS_MEMORYSTATS.containing_type = _SYSTEMSTATS
_SYSTEMSTATS.fields_by_name['load'].message_type = _SYSTEMSTATS_LOADSTATS
_SYSTEMSTATS.fields_by_name['cpu'].message_type = _SYSTEMSTATS_CPUSTATS
_SYSTEMSTATS.fields_by_name['memory'].message_type = _SYSTEMSTATS_MEMORYSTATS
_COMPONENTSTATS_CPUSTATS.containing_type = _COMPONENTSTATS
_COMPONENTSTATS_MEMORYSTATS.containing_type = _COMPONENTSTATS
_COMPONENTSTATS.fields_by_name['cpu'].message_type = _COMPONENTSTATS_CPUSTATS
_COMPONENTSTATS.fields_by_name['memory'].message_type = _COMPONENTSTATS_MEMORYSTATS
DESCRIPTOR.message_types_by_name['Percentiles'] = _PERCENTILES
DESCRIPTOR.message_types_by_name['Rates'] = _RATES
DESCRIPTOR.message_types_by_name['SystemStats'] = _SYSTEMSTATS
DESCRIPTOR.message_types_by_name['ComponentStats'] = _COMPONENTSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Percentiles = _reflection.GeneratedProtocolMessageType('Percentiles', (_message.Message,), dict(
  DESCRIPTOR = _PERCENTILES,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.Percentiles)
  ))
_sym_db.RegisterMessage(Percentiles)

Rates = _reflection.GeneratedProtocolMessageType('Rates', (_message.Message,), dict(
  DESCRIPTOR = _RATES,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.Rates)
  ))
_sym_db.RegisterMessage(Rates)

SystemStats = _reflection.GeneratedProtocolMessageType('SystemStats', (_message.Message,), dict(

  Loadstats = _reflection.GeneratedProtocolMessageType('Loadstats', (_message.Message,), dict(
    DESCRIPTOR = _SYSTEMSTATS_LOADSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.SystemStats.Loadstats)
    ))
  ,

  CPUStats = _reflection.GeneratedProtocolMessageType('CPUStats', (_message.Message,), dict(
    DESCRIPTOR = _SYSTEMSTATS_CPUSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.SystemStats.CPUStats)
    ))
  ,

  MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), dict(
    DESCRIPTOR = _SYSTEMSTATS_MEMORYSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.SystemStats.MemoryStats)
    ))
  ,
  DESCRIPTOR = _SYSTEMSTATS,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.SystemStats)
  ))
_sym_db.RegisterMessage(SystemStats)
_sym_db.RegisterMessage(SystemStats.Loadstats)
_sym_db.RegisterMessage(SystemStats.CPUStats)
_sym_db.RegisterMessage(SystemStats.MemoryStats)

ComponentStats = _reflection.GeneratedProtocolMessageType('ComponentStats', (_message.Message,), dict(

  CPUStats = _reflection.GeneratedProtocolMessageType('CPUStats', (_message.Message,), dict(
    DESCRIPTOR = _COMPONENTSTATS_CPUSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.ComponentStats.CPUStats)
    ))
  ,

  MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), dict(
    DESCRIPTOR = _COMPONENTSTATS_MEMORYSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.ComponentStats.MemoryStats)
    ))
  ,
  DESCRIPTOR = _COMPONENTSTATS,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.ComponentStats)
  ))
_sym_db.RegisterMessage(ComponentStats)
_sym_db.RegisterMessage(ComponentStats.CPUStats)
_sym_db.RegisterMessage(ComponentStats.MemoryStats)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\030org.thethingsnetwork.apiB\010APIProtoP\001Z\037github_com/TheThingsNetwork/api\252\002\024TheThingsNetwork.API'))
try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
